==> ejc-analysis-api-3.0.0-20230712.091259-67-sources.jar: com/ejianc/business/analysis/vo/FeeVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 现场管理费
 * 
 * @author generator
 * 
 */
public class FeeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId;
    private String orgCode;
    private String orgName;
    private Long projectDepartmentId;
    private Long twoOrgId;
    private String twoOrgCode;
    private String twoOrgName;
    private Long projectId;
    private String projectCode;
    private String projectName;
    private Integer projectStatus;
    private String projectStatusName;
    private String reportingMonth;
    private BigDecimal yearProduction;
    private BigDecimal sumProduction;
    private BigDecimal yearFee;
    private BigDecimal sumFee;
    private BigDecimal yearRate;
    private BigDecimal sumRate;
    private String memo;
    private Date projectCreateTime;
    private Date costAnalysisCreateTime;
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private Integer orgStatusOrder; // 二级组织排序

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织编码
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 所属组织编码
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 二级组织id
     */
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    /**
     * 二级组织id
     */
    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    /**
     * 二级组织编码
     */
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    /**
     * 二级组织编码
     */
    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    /**
     * 二级组织名称
     */
    public String getTwoOrgName() {
        return twoOrgName;
    }

    /**
     * 二级组织名称
     */
    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目编码
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编码
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目状态
     */
    public Integer getProjectStatus() {
        return projectStatus;
    }

    /**
     * 项目状态
     */
    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    /**
     * 实际完成产值(本年)
     */
    public BigDecimal getYearProduction() {
        return yearProduction;
    }

    /**
     * 实际完成产值(本年)
     */
    public void setYearProduction(BigDecimal yearProduction) {
        this.yearProduction = yearProduction;
    }
    /**
     * 实际完成产值(累计)
     */
    public BigDecimal getSumProduction() {
        return sumProduction;
    }

    /**
     * 实际完成产值(累计)
     */
    public void setSumProduction(BigDecimal sumProduction) {
        this.sumProduction = sumProduction;
    }
    /**
     * 现场管理费(本年)
     */
    public BigDecimal getYearFee() {
        return yearFee;
    }

    /**
     * 现场管理费(本年)
     */
    public void setYearFee(BigDecimal yearFee) {
        this.yearFee = yearFee;
    }
    /**
     * 现场管理费(累计)
     */
    public BigDecimal getSumFee() {
        return sumFee;
    }

    /**
     * 现场管理费(累计)
     */
    public void setSumFee(BigDecimal sumFee) {
        this.sumFee = sumFee;
    }
    /**
     * 当年占比
     */
    public BigDecimal getYearRate() {
        return yearRate;
    }

    /**
     * 当年占比
     */
    public void setYearRate(BigDecimal yearRate) {
        this.yearRate = yearRate;
    }
    /**
     * 开累占比
     */
    public BigDecimal getSumRate() {
        return sumRate;
    }

    /**
     * 开累占比
     */
    public void setSumRate(BigDecimal sumRate) {
        this.sumRate = sumRate;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 项目创建日期
     */
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    /**
     * 项目创建日期
     */
    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    /**
     * 月度分析报告创建时间
     */
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    /**
     * 月度分析报告创建时间
     */
    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    
}

==> ejc-analysis-api-3.0.0-20240402.064551-149-sources.jar: com/ejianc/business/analysis/vo/FeeVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 现场管理费
 * 
 * @author generator
 * 
 */
public class FeeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId;
    private String orgCode;
    private String orgName;
    private Long projectDepartmentId;
    private Long twoOrgId;
    private String twoOrgCode;
    private String twoOrgName;
    private Long projectId;
    private String projectCode;
    private String projectName;
    private Integer projectStatus;
    private String projectStatusName;
    private String reportingMonth;
    private BigDecimal yearProduction;
    private BigDecimal sumProduction;
    private BigDecimal yearFee;
    private BigDecimal sumFee;
    private BigDecimal yearRate;
    private BigDecimal sumRate;
    private String memo;
    private Date projectCreateTime;
    private Date costAnalysisCreateTime;
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private Integer orgStatusOrder; // 二级组织排序
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }
    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织编码
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 所属组织编码
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 二级组织id
     */
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    /**
     * 二级组织id
     */
    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    /**
     * 二级组织编码
     */
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    /**
     * 二级组织编码
     */
    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    /**
     * 二级组织名称
     */
    public String getTwoOrgName() {
        return twoOrgName;
    }

    /**
     * 二级组织名称
     */
    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目编码
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编码
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目状态
     */
    public Integer getProjectStatus() {
        return projectStatus;
    }

    /**
     * 项目状态
     */
    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    /**
     * 实际完成产值(本年)
     */
    public BigDecimal getYearProduction() {
        return yearProduction;
    }

    /**
     * 实际完成产值(本年)
     */
    public void setYearProduction(BigDecimal yearProduction) {
        this.yearProduction = yearProduction;
    }
    /**
     * 实际完成产值(累计)
     */
    public BigDecimal getSumProduction() {
        return sumProduction;
    }

    /**
     * 实际完成产值(累计)
     */
    public void setSumProduction(BigDecimal sumProduction) {
        this.sumProduction = sumProduction;
    }
    /**
     * 现场管理费(本年)
     */
    public BigDecimal getYearFee() {
        return yearFee;
    }

    /**
     * 现场管理费(本年)
     */
    public void setYearFee(BigDecimal yearFee) {
        this.yearFee = yearFee;
    }
    /**
     * 现场管理费(累计)
     */
    public BigDecimal getSumFee() {
        return sumFee;
    }

    /**
     * 现场管理费(累计)
     */
    public void setSumFee(BigDecimal sumFee) {
        this.sumFee = sumFee;
    }
    /**
     * 当年占比
     */
    public BigDecimal getYearRate() {
        return yearRate;
    }

    /**
     * 当年占比
     */
    public void setYearRate(BigDecimal yearRate) {
        this.yearRate = yearRate;
    }
    /**
     * 开累占比
     */
    public BigDecimal getSumRate() {
        return sumRate;
    }

    /**
     * 开累占比
     */
    public void setSumRate(BigDecimal sumRate) {
        this.sumRate = sumRate;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 项目创建日期
     */
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    /**
     * 项目创建日期
     */
    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    /**
     * 月度分析报告创建时间
     */
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    /**
     * 月度分析报告创建时间
     */
    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    
}
